@@ -1,10 +1,15 @@
-from os import getenv
+from os import getenv, system
 import pandas as pd
 import mariadb
 import sys
 from elasticsearch import Elasticsearch
 import spacy
-nlp = spacy.load('es_core_news_md', disable=['parser','ner','textcat','...'] )
+
+try:
+    nlp = spacy.load('es_core_news_md', disable=['parser','ner','textcat','...'] )
+except:
+    system("python -m spacy download es_core_news_md")
+    nlp = spacy.load('es_core_news_md', disable=['parser','ner','textcat','...'] )
 
 
 
